from __future__ import annotations

import dataclasses

from ldaptool._utils import argclasses


@dataclasses.dataclass(slots=True, kw_only=True)
class Arguments(argclasses.BaseArguments):
    json: bool = dataclasses.field(
        default=False,
        metadata=argclasses.arg(help="Use full json output"),
    )
    human: bool = dataclasses.field(
        default=False,
        metadata=argclasses.arg(help="Use simple json output (join multiple values of one attribute)"),
    )
    human_separator: str = dataclasses.field(
        default=", ",
        metadata=argclasses.arg(help="Separator to join multiple values of one attribute with (default: %(default)r)"),
    )
    dateonly: bool = dataclasses.field(
        default=True,
        metadata=argclasses.arg(help="Use only date part of decoded timestamps"),
    )
    dndomain: bool = dataclasses.field(
        default=False,
        metadata=argclasses.arg(help="Whether to export a virtual dndomain attribute (DNS domain from dn)"),
    )
    dnpath: bool = dataclasses.field(
        default=False,
        metadata=argclasses.arg(
            help="""
                Whether to export a virtual dnpath attribute
                ('/' joined values of reversed DN without DNS labels)
            """
        ),
    )
    dnfullpath: bool = dataclasses.field(
        default=False,
        metadata=argclasses.arg(
            help="""
                Whether to export a virtual dnfullpath attribute
                ('/' joined values of reversed DN; DNS domain as first label)
            """
        ),
    )
