from __future__ import annotations

import typing

import ldap

from ldaptool._utils.ldap import Result, ldap_search_ext

from .arguments import Arguments
from .config import Config


def search(*, config: Config, arguments: Arguments) -> typing.Iterable[Result]:
    if not arguments.realm in config.realms:
        raise SystemExit(f"Unknown realm {arguments.realm}")
    realm = config.realms[arguments.realm]

    ## fixup arguments base on config/realm
    if realm.account is None:
        arguments.krb = True
    if not arguments.base:
        arguments.base = realm.default_base(gc=arguments.gc)

    ldap_con = ldap.initialize(realm.ldap_uri(gc=arguments.gc, tls=False, server=arguments.server))
    ldap_con.set_option(ldap.OPT_REFERRALS, 0)
    if arguments.krb:
        ldap_con.sasl_gssapi_bind_s()
    else:
        ldap_con.simple_bind_s(realm.account, config.get_password(realm))

    assert arguments.base
    assert arguments.filter

    return ldap_search_ext(
        ldap_con,
        base=arguments.base,
        filterstr=arguments.filter,
        attrlist=arguments.attributes,
        sizelimit=0 if arguments.all else 1000,
    )
